==> RSTouchscreenNG-1.3.0.zip: RSTouchscreenNG/projects/front-ui/src/lib/modals/licence-keyboard.service.ts <==
/* (C) 2016-2021 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, Injectable, NgModule, OnInit, OnDestroy} from "@angular/core";
import {CommonModule} from "@angular/common";
import {RSModal} from "./rsModal.component";
import {RSModalViewComponent} from "./modal-view.component";
import {RSModalHeadComponent} from "./modal-head.component";
import {RSModelContentComponent} from "./modal-content.component";
import {RSModelFooterComponent} from "./modal-footer.component";
import {DomSanitizer, SafeHtml} from "@angular/platform-browser";

@Component({
  selector: "rs-licence-keyboard-modal",
  template: `<div class="rs-string-keyboard-modal">
    <rs-modal-head><h1><span [innerHTML]="head"></span><div class="close" (rsClick)="modal.cancel()"><i class="fa fa-close"></i></div></h1></rs-modal-head>
    <rs-modal-content>
        <div style="padding:2px 5px">
            <div class="input"><span [innerHTML]="valueShow"></span></div>
        </div>
        <div class="error" [innerHTML]="error"></div>

        <div>
            <div class="keyboard-string">
                <div class="keyboard">
                    <div (rsClickUp)="key('1')" class="key key-2">
                        <div>1</div>
                    </div>
                    <div (rsClickUp)="key('2')" class="key key-2">
                        <div>2</div>
                    </div>
                    <div (rsClickUp)="key('3')" class="key key-2">
                        <div>3</div>
                    </div>
                    <div (rsClickUp)="key('4')" class="key key-2">
                        <div>4</div>
                    </div>
                    <div (rsClickUp)="key('5')" class="key key-2">
                        <div>5</div>
                    </div>
                    <div (rsClickUp)="key('6')" class="key key-2">
                        <div>6</div>
                    </div>
                    <div (rsClickUp)="key('7')" class="key key-2">
                        <div>7</div>
                    </div>
                    <div (rsClickUp)="key('8')" class="key key-2">
                        <div>8</div>
                    </div>
                    <div (rsClickUp)="key('9')" class="key key-2">
                        <div>9</div>
                    </div>
                    <div (rsClickUp)="key('0')" class="key key-2">
                        <div>0</div>
                    </div>
                </div>
                <div class="keyboard">
                    <div (rsClickUp)="key('Q')" class="key key-2">
                        <div>Q</div>
                    </div>
                    <div (rsClickUp)="key('W')" class="key key-2">
                        <div>W</div>
                    </div>
                    <div (rsClickUp)="key('E')" class="key key-2">
                        <div>E</div>
                    </div>
                    <div (rsClickUp)="key('R')" class="key key-2">
                        <div>R</div>
                    </div>
                    <div (rsClickUp)="key('T')" class="key key-2">
                        <div>T</div>
                    </div>
                    <div (rsClickUp)="key('Y')" class="key key-2">
                        <div>Y</div>
                    </div>
                    <div (rsClickUp)="key('U')" class="key key-2">
                        <div>U</div>
                    </div>
                    <div (rsClickUp)="key('I')" class="key key-2">
                        <div>I</div>
                    </div>
                    <div (rsClickUp)="key('O')" class="key key-2">
                        <div>O</div>
                    </div>
                    <div (rsClickUp)="key('P')" class="key key-2">
                        <div>P</div>
                    </div>
                </div>
                <div class="keyboard">
                    <div (rsClickUp)="key('A')" class="key key-2">
                        <div>A</div>
                    </div>
                    <div (rsClickUp)="key('S')" class="key key-2">
                        <div>S</div>
                    </div>
                    <div (rsClickUp)="key('D')" class="key key-2">
                        <div>D</div>
                    </div>
                    <div (rsClickUp)="key('F')" class="key key-2">
                        <div>F</div>
                    </div>
                    <div (rsClickUp)="key('G')" class="key key-2">
                        <div>G</div>
                    </div>
                    <div (rsClickUp)="key('H')" class="key key-2">
                        <div>H</div>
                    </div>
                    <div (rsClickUp)="key('J')" class="key key-2">
                        <div>J</div>
                    </div>
                    <div (rsClickUp)="key('K')" class="key key-2">
                        <div>K</div>
                    </div>
                    <div (rsClickUp)="key('L')" class="key key-2">
                        <div>L</div>
                    </div>
                    <div (rsClickUp)="del()" class="key key-2">
                        <div class="rs rs-backspace"></div>
                    </div>
                </div>
                <div class="keyboard">
                    <div (rsClickUp)="key('Z')" class="key key-2">
                        <div>Z</div>
                    </div>
                    <div (rsClickUp)="key('X')" class="key key-2">
                        <div>X</div>
                    </div>
                    <div (rsClickUp)="key('C')" class="key key-2">
                        <div>C</div>
                    </div>
                    <div (rsClickUp)="key('V')" class="key key-2">
                        <div>V</div>
                    </div>
                    <div (rsClickUp)="key('B')" class="key key-2">
                        <div>B</div>
                    </div>
                    <div (rsClickUp)="key('N')" class="key key-2">
                        <div>N</div>
                    </div>
                    <div (rsClickUp)="key('M')" class="key key-2">
                        <div>M</div>
                    </div>
                    <div (rsClickUp)="send()" class="key key-6" [class.disabled]="value.length!=29">
                        <div class="fa fa-level-down fa-rotate-90"></div>
                    </div>
                </div>
            </div>
        </div>
    </rs-modal-content>
</div>`
})
export class RSLicenceKeyboardModalComponent implements OnInit, OnDestroy {
  value = "";
  valueShow = "";
  head: SafeHtml = "";
  error = "&nbsp;";
  options: any = {};
  hasError = false;

  constructor(public modal: RSModalViewComponent,
              private sanitizer: DomSanitizer) {
    this.options = this.modal.data;
    this.value = this.modal.data.defaultValue;
    this.head = this.sanitizer.bypassSecurityTrustHtml(this.modal.data.head);
    document.body.addEventListener("keydown", this.keyHandler);
    this.update();
  }

  ngOnDestroy() {
    document.body.removeEventListener("keydown", this.keyHandler);
  }

  keyHandler = (event) => {
    const k = event.key.toUpperCase();
    if (k.length === 1 && ((k >= "0" && k <= "9") || (k >= "A" && k <= "Z"))) {
      this.key(k);
    } else if (event.code === "Backspace" || event.code === "Delete") {
      this.del();
    } else if (k === 'ENTER') {
      this.send();
    }
  }

  ngOnInit() {
  }

  update() {
    this.valueShow = this.value.split(" ").join("&nbsp;");
    if (this.valueShow.length === 0) {
      this.valueShow = "&nbsp;";
    }
    this.error = "&nbsp;";
    this.hasError = false;
    if (this.options.minLength && this.value.length < this.options.minLength) {
      this.hasError = true;
      this.error = "<?php _('Min. length is @ chars!') ?>".replace("@", this.options.minLength);
    }
    if (this.options.maxLength && this.value.length > this.options.maxLength) {
      this.hasError = true;
      this.error = "<?php _('Max. length is @ chars!') ?>".replace("@", this.options.maxLength);
    }
  }

  key(k) {
    if (this.value.length === 29) {
      return;
    }
    this.value += k;
    const l = this.value.length;
    if (l === 5 || l === 11 || l === 17 || l === 23) {
      this.value += "-";
    }
    this.update();
  }

  del() {
    const l = this.value.length;
    if (l > 0) {
      this.value = this.value.substr(0, this.value.length - (l === 6 || l === 12 || l === 18 || l === 24 ? 2 : 1));
    }
    this.update();
  }

  send() {
    if (this.value.length === 29) {
      this.modal.close(this.value);
    }
  }
}

@Injectable()
export class RSLicenceKeyboard {
  constructor(public modal: RSModal) {
  }

  getString(oldValue: string, head: string, options?: any): Promise<any> {
    if (!options) {
      options = {};
    }
    options.defaultValue = oldValue;
    options.head = head;
    options.modalClass = "modal-noborder";
    return this.modal.show(RSLicenceKeyboardModalComponent, options);
  }
}

==> RSTouchscreenNG-1.4.16.zip: RSTouchscreenNG/projects/front-ui/src/lib/modals/licence-keyboard.service.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, Injectable, OnDestroy} from "@angular/core";
import {RSModal} from "./rsModal.component";
import {RSModalViewComponent} from "./modal-view.component";
import {DomSanitizer, SafeHtml} from "@angular/platform-browser";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
  selector: "rs-licence-keyboard-modal",
  template: `<div class="rs-string-keyboard-modal">
    <rs-modal-head><h1><span [innerHTML]="head"></span><div class="close" (rsClick)="modal.cancel()"><i class="fa fa-close"></i></div></h1></rs-modal-head>
    <rs-modal-content>
        <div style="padding:2px 5px">
            <div class="input"><span [innerHTML]="valueShow"></span></div>
        </div>
        <div class="error" [innerHTML]="error"></div>

        <div>
            <div class="keyboard-string">
                <div class="keyboard">
                    <div (rsClickUp)="key('1')" class="key key-2">
                        <div>1</div>
                    </div>
                    <div (rsClickUp)="key('2')" class="key key-2">
                        <div>2</div>
                    </div>
                    <div (rsClickUp)="key('3')" class="key key-2">
                        <div>3</div>
                    </div>
                    <div (rsClickUp)="key('4')" class="key key-2">
                        <div>4</div>
                    </div>
                    <div (rsClickUp)="key('5')" class="key key-2">
                        <div>5</div>
                    </div>
                    <div (rsClickUp)="key('6')" class="key key-2">
                        <div>6</div>
                    </div>
                    <div (rsClickUp)="key('7')" class="key key-2">
                        <div>7</div>
                    </div>
                    <div (rsClickUp)="key('8')" class="key key-2">
                        <div>8</div>
                    </div>
                    <div (rsClickUp)="key('9')" class="key key-2">
                        <div>9</div>
                    </div>
                    <div (rsClickUp)="key('0')" class="key key-2">
                        <div>0</div>
                    </div>
                </div>
                <div class="keyboard">
                    <div (rsClickUp)="key('Q')" class="key key-2">
                        <div>Q</div>
                    </div>
                    <div (rsClickUp)="key('W')" class="key key-2">
                        <div>W</div>
                    </div>
                    <div (rsClickUp)="key('E')" class="key key-2">
                        <div>E</div>
                    </div>
                    <div (rsClickUp)="key('R')" class="key key-2">
                        <div>R</div>
                    </div>
                    <div (rsClickUp)="key('T')" class="key key-2">
                        <div>T</div>
                    </div>
                    <div (rsClickUp)="key('Y')" class="key key-2">
                        <div>Y</div>
                    </div>
                    <div (rsClickUp)="key('U')" class="key key-2">
                        <div>U</div>
                    </div>
                    <div (rsClickUp)="key('I')" class="key key-2">
                        <div>I</div>
                    </div>
                    <div (rsClickUp)="key('O')" class="key key-2">
                        <div>O</div>
                    </div>
                    <div (rsClickUp)="key('P')" class="key key-2">
                        <div>P</div>
                    </div>
                </div>
                <div class="keyboard">
                    <div (rsClickUp)="key('A')" class="key key-2">
                        <div>A</div>
                    </div>
                    <div (rsClickUp)="key('S')" class="key key-2">
                        <div>S</div>
                    </div>
                    <div (rsClickUp)="key('D')" class="key key-2">
                        <div>D</div>
                    </div>
                    <div (rsClickUp)="key('F')" class="key key-2">
                        <div>F</div>
                    </div>
                    <div (rsClickUp)="key('G')" class="key key-2">
                        <div>G</div>
                    </div>
                    <div (rsClickUp)="key('H')" class="key key-2">
                        <div>H</div>
                    </div>
                    <div (rsClickUp)="key('J')" class="key key-2">
                        <div>J</div>
                    </div>
                    <div (rsClickUp)="key('K')" class="key key-2">
                        <div>K</div>
                    </div>
                    <div (rsClickUp)="key('L')" class="key key-2">
                        <div>L</div>
                    </div>
                    <div (rsClickUp)="del()" class="key key-2">
                        <div class="rs rs-backspace"></div>
                    </div>
                </div>
                <div class="keyboard">
                    <div (rsClickUp)="key('Z')" class="key key-2">
                        <div>Z</div>
                    </div>
                    <div (rsClickUp)="key('X')" class="key key-2">
                        <div>X</div>
                    </div>
                    <div (rsClickUp)="key('C')" class="key key-2">
                        <div>C</div>
                    </div>
                    <div (rsClickUp)="key('V')" class="key key-2">
                        <div>V</div>
                    </div>
                    <div (rsClickUp)="key('B')" class="key key-2">
                        <div>B</div>
                    </div>
                    <div (rsClickUp)="key('N')" class="key key-2">
                        <div>N</div>
                    </div>
                    <div (rsClickUp)="key('M')" class="key key-2">
                        <div>M</div>
                    </div>
                    <div (rsClickUp)="send()" class="key key-6" [class.disabled]="value.length!==29">
                        <div class="fa fa-level-down fa-rotate-90"></div>
                    </div>
                </div>
            </div>
        </div>
    </rs-modal-content>
</div>`
})
export class RSLicenceKeyboardModalComponent implements OnDestroy {
  value = "";
  valueShow = "";
  head: SafeHtml = "";
  error = "&nbsp;";
  options: any = {};
  hasError = false;

  constructor(public modal: RSModalViewComponent,
              private sanitizer: DomSanitizer) {
    this.options = this.modal.data;
    this.value = this.modal.data.defaultValue;
    this.head = this.sanitizer.bypassSecurityTrustHtml(this.modal.data.head);
    document.body.addEventListener("keydown", this.keyHandler);
    this.update();
  }

  ngOnDestroy() {
    document.body.removeEventListener("keydown", this.keyHandler);
  }

  keyHandler = (event) => {
    const k = event.key.toUpperCase();
    if (k.length === 1 && ((k >= "0" && k <= "9") || (k >= "A" && k <= "Z"))) {
      this.key(k);
    } else if (event.code === "Backspace" || event.code === "Delete") {
      this.del();
    } else if (k === 'ENTER') {
      this.send();
    }
  }

  update() {
    this.valueShow = this.value.split(" ").join("&nbsp;");
    if (this.valueShow.length === 0) {
      this.valueShow = "&nbsp;";
    }
    this.error = "&nbsp;";
    this.hasError = false;
    if (this.options.minLength && this.value.length < this.options.minLength) {
      this.hasError = true;
      this.error = "<?php _('Min. length is @ chars!') ?>".replace("@", this.options.minLength);
    }
    if (this.options.maxLength && this.value.length > this.options.maxLength) {
      this.hasError = true;
      this.error = "<?php _('Max. length is @ chars!') ?>".replace("@", this.options.maxLength);
    }
  }

  key(k) {
    if (this.value.length === 29) {
      return;
    }
    this.value += k;
    const l = this.value.length;
    if (l === 5 || l === 11 || l === 17 || l === 23) {
      this.value += "-";
    }
    this.update();
  }

  del() {
    const l = this.value.length;
    if (l > 0) {
      this.value = this.value.substr(0, this.value.length - (l === 6 || l === 12 || l === 18 || l === 24 ? 2 : 1));
    }
    this.update();
  }

  send() {
    if (this.value.length === 29) {
      this.modal.close(this.value);
    }
  }
}

@Injectable()
export class RSLicenceKeyboard {
  constructor(public modal: RSModal) {
  }

  getString(oldValue: string, head: string, options?: any): Promise<any> {
    if (!options) {
      options = {};
    }
    options.defaultValue = oldValue;
    options.head = head;
    options.modalClass = "modal-noborder";
    return this.modal.show(RSLicenceKeyboardModalComponent, options);
  }
}
